@@ -121,10 +121,9 @@ PROGNAME " %s\n"
 " -m, --bitrate-mode <n>        Bitrate configuration\n"
 "                                 0: CBR (default)\n"
 "                                 1-5: VBR\n"
-"                               (VBR mode is not officially supported, and\n"
-"                                works only on a certain combination of\n"
-"                                parameter settings, sample rate, and\n"
-"                                channel configuration)\n"
+"                               (VBR mode 1 is tuned for HE-AAC v2\n"
+"                                VBR mode 2 is tuned for HE-AAC\n"
+"                                VBR mode 3 or greater is for AAC LC)\n"
 " -w, --bandwidth <n>           Frequency bandwidth in Hz (AAC LC only)\n"
 " -a, --afterburner <n>         Afterburner\n"
 "                                 0: Off\n"
@@ -159,6 +158,7 @@ PROGNAME " %s\n"
 " -I, --ignorelength            Ignore length of WAV header\n"
 " -S, --silent                  Don't print progress messages\n"
 " --moov-before-mdat            Place moov box before mdat box on m4a output\n"
+" --no-timestamp                Don't inject timestamp in the file\n"
 "\n"
 "Options for raw (headerless) input:\n"
 " -R, --raw                     Treat input as raw (by default WAV is\n"
@@ -221,6 +221,8 @@ typedef struct aacenc_param_ex_t {
     unsigned raw_rate;
     const char *raw_format;
 
+    int no_timestamp;
+
     aacenc_tag_store_t tags;
     aacenc_tag_store_t source_tags;
     aacenc_translate_generic_text_tag_ctx_t source_tag_ctx;
@@ -244,7 +246,7 @@ int parse_options(int argc, char **argv, aacenc_param_ex_t *params)
 #define OPT_LONG_TAG             M4AF_FOURCC('l','t','a','g')
 #define OPT_TAG_FROM_JSON        M4AF_FOURCC('t','f','j','s')
 
-    static struct option long_options[] = {
+    static const struct option long_options[] = {
         { "help",             no_argument,       0, 'h' },
         { "profile",          required_argument, 0, 'p' },
         { "bitrate",          required_argument, 0, 'b' },
@@ -284,6 +286,8 @@ int parse_options(int argc, char **argv, aacenc_param_ex_t *params)
         { "tag-from-file",    required_argument, 0, OPT_SHORT_TAG_FILE     },
         { "long-tag",         required_argument, 0, OPT_LONG_TAG           },
         { "tag-from-json",    required_argument, 0, OPT_TAG_FROM_JSON      },
+
+        { "no-timestamp",     no_argument,       0, '#' },
         { 0,                  0,                 0, 0                      },
     };
     params->afterburner = 1;
@@ -456,6 +460,9 @@ int parse_options(int argc, char **argv, aacenc_param_ex_t *params)
         case OPT_TAG_FROM_JSON:
             params->json_filename = optarg;
             break;
+        case '#':
+            params->no_timestamp = 1;
+            break;
         default:
             return usage(), -1;
         }
@@ -513,7 +520,7 @@ int encode(aacenc_param_ex_t *params, pcm_reader_t *reader,
            HANDLE_AACENCODER encoder, uint32_t frame_length, 
            m4af_ctx_t *m4af)
 {
-    int16_t *ibuf = 0, *ip;
+    INT_PCM *ibuf = 0, *ip;
     aacenc_frame_t obuf[2] = {{ 0 }}, *obp;
     unsigned flip = 0;
     int nread = 1;
@@ -833,7 +840,7 @@ int main(int argc, char **argv)
         unsigned framelen = aacinfo.frameLength;
         scale = sample_format->sample_rate >> scale_shift;
         if ((m4af = m4af_create(M4AF_CODEC_MP4A, scale, &m4af_io,
-                                params.output_fp)) < 0)
+                                params.output_fp, params.no_timestamp)) < 0)
             goto END;
         m4af_set_num_channels(m4af, 0, sample_format->channels_per_frame);
         m4af_set_fixed_frame_duration(m4af, 0, framelen >> scale_shift);
